﻿
// Code goes here
var app = angular.module("Sample", ["ngAnimate", "ngResource", "ui.bootstrap", "wj"]);
app.controller("conLinkedGrids", ["$scope", "$http", "$timeout", conLinkedGrids]);
function conLinkedGrids($scope, $http, $timeout) {
	var vm = this;
	vm.employees = [];
	vm.salesOrders = [];
	vm.salesTotals = [];
	vm.cvSalesPeople = null;
	vm.cvSalesOrders = null;
	vm.employeeCount = 0;
	vm.orderCount = 0;
	vm.ordersForEmployeeCount = 0;
	vm.dataReady = false;
	vm.data2Ready = false;
	vm.heading = "Employees";
	vm.flexGridList = null;
	vm.flexGridChild = null;
	vm.pieChart = null;
	vm.getEmployees = getEmployees;
	vm.rowSelected = rowSelected;
	vm.loadSalesPeople = loadSalesPeople;
	vm.loadOrders = loadOrders;
	vm.loadOrderChart = loadOrderChart;
	vm.showGridTab = showGridTab;
	vm.showGraphTab = showGraphTab;
	vm.refreshGrid = refreshGrid;
	vm.refreshChart = refreshChart;
	vm.currentEmployee = null;
	_init();
	function _init() {
		getEmployees();
	}
	function _SetupSalesGroups() {
		// Create Group and Sales Order collection view
		var salesGridData = new wijmo.collections.ObservableArray(vm.salesOrders);
		var yearMonthGroup = new wijmo.collections.PropertyGroupDescription("OrderDate", function (item, prop) {
			if (item !== null) { return moment(item.OrderDate).format("MM/YYYY"); } else { return; }
		});
		vm.cvSalesOrders = new wijmo.collections.CollectionView(salesGridData);
		vm.cvSalesOrders.groupDescriptions.push(yearMonthGroup);
	}
	function _SetupSalesPeople() {
		// Create SalesPeople view
		var salesChartData = new wijmo.collections.ObservableArray(vm.salesOrders);
		vm.cvSalesPeople = new wijmo.collections.CollectionView(vm.employees);
	}
	function _SetupSalesChart() {
		// Create Group and Pie Chart collection view
	}
	function rowSelected() {
		var newEm = vm.flexGridList.selectedRows[0].dataItem;
		vm.currentEmployee = newEm;
		if (newEm) {
			getSalesOrderHeaders(newEm.BusinessEntityID);
			getSalesOrderTotals(newEm.BusinessEntityID)
		}
	}
	function loadSalesPeople() {
		getEmployees();
	}
	function loadOrders() {
		var newEm = vm.flexGridList.selectedRows[0].dataItem;
		vm.currentEmployee = newEm;
		getSalesOrderHeaders(newEm.BusinessEntityID)
	}
	function loadOrderChart() {
		var newEm = vm.flexGridList.selectedRows[0].dataItem;
		vm.currentEmployee = newEm;
		getSalesOrderTotals(newEm.BusinessEntityID)
	}
	function getEmployees() {
		console.log("Reading Employees from JSON file");
		$http.get("SalesPeople.json").then(function (resp) {
			console.log("Received Employees from JSON file");
			vm.employeeCount = resp.data.length;
			vm.dataReady = true;
			vm.employees = resp.data;
			_SetupSalesPeople();
			$timeout(function () { rowSelected(); });
		});
	}
	function getSalesOrderHeaders(userId) {
		console.log("Reading Sales Order Headers from JSON file");
		$http.get("SalesOrderHeaders.json").then(function (resp) {
			console.log("Received Sales Order Headers from JSON file");
			var data = resp.data.filter(function (item) {
				return (item.SalesPersonID === userId)
			});
			vm.salesOrders = data;
			vm.orderCount = resp.data.length;
			vm.ordersForEmployeeCount = data.length;
			vm.data2Ready = true;
			_SetupSalesGroups();
		});
	}
	function getSalesOrderTotals(userId) {
		console.log("Reading Sales Order Headers from JSON file");
		$http.get("SalesOrderHeaders.json").then(function (resp) {
			console.log("Received Sales Order Headers from JSON file");
			var data = resp.data.filter(function (item) {
				return (item.SalesPersonID === userId)
			});
			// aggregate the sales data
			vm.salesTotals = [];
			for (var ix = 0; ix < data.length; ix++) {
				var item = data[ix];
				var groupString = moment(item.OrderDate).format("YYYY");
				var aggSearch = vm.salesTotals.filter(function (a) {
					return (a.Group == groupString);
				})
				if (aggSearch[0] == null) {
					aggItem = {
						Group: groupString,
						Total: item.SubTotal,
						Count: 1
					};
					vm.salesTotals.push(aggItem);
				} else {
					aggSearch[0].Count++;
					aggSearch[0].Total = aggSearch[0].Total + item.SubTotal;
				}
			}
			_SetupSalesChart();
		});
	}

	function showGridTab() {
		//if (vm.salesOrders.length == 0) { rowSelected(); }
		//vm.flexGridChild.refresh();
		$timeout(function () { vm.flexGridChild.invalidate();})
	}

	function showGraphTab() {
		//if (vm.salesTotals.length == 0) { loadOrderChart(); }
		//vm.pieChart.refresh();
		$timeout(function () { vm.pieChart.invalidate(); })
	}

	function refreshGrid(mode) {
		switch (mode) {
			case "I":
				vm.flexGridChild.invalidate();
				break;
			default:
				vm.flexGridChild.refresh();
		}
	}

	function refreshChart(mode) {
		switch (mode) {
			case "I":
				vm.pieChart.invalidate();
				break;
			default:
				vm.pieChart.refresh();
		}
	}

}